@@ -1,40 +1,41 @@
 """Window used for game installers"""
+# Standard Library
 import os
 import time
 import webbrowser
+from gettext import gettext as _
 
+# Third Party Libraries
 from gi.repository import Gtk
 
+# Lutris Modules
 from lutris import api, pga, settings
-from lutris.installer import interpreter
-from lutris.installer.errors import ScriptingError, MissingGameDependency
 from lutris.game import Game
 from lutris.gui.config.add_game import AddGameDialog
-from lutris.gui.dialogs import (
-    NoInstallerDialog, DirectoryDialog, InstallerSourceDialog, QuestionDialog
-)
-from lutris.gui.widgets.download_progress import DownloadProgressBox
+from lutris.gui.dialogs import DirectoryDialog, InstallerSourceDialog, NoInstallerDialog, QuestionDialog
 from lutris.gui.widgets.common import FileChooserEntry, InstallerLabel
+from lutris.gui.widgets.download_progress import DownloadProgressBox
 from lutris.gui.widgets.installer import InstallerPicker
 from lutris.gui.widgets.log_text_view import LogTextView
 from lutris.gui.widgets.window import BaseApplicationWindow
-
-from lutris.util import jobs
-from lutris.util import system
-from lutris.util import xdgshortcuts
+from lutris.installer import interpreter
+from lutris.installer.errors import MissingGameDependency, ScriptingError
+from lutris.util import jobs, system, xdgshortcuts
 from lutris.util.log import logger
 from lutris.util.strings import add_url_tags, escape_gtk_label
 
 
-class InstallerWindow(BaseApplicationWindow):
+class InstallerWindow(BaseApplicationWindow):  # pylint: disable=too-many-public-methods
+
     """GUI for the install process."""
+
     def __init__(
-            self,
-            game_slug=None,
-            installer_file=None,
-            revision=None,
-            parent=None,
-            application=None,
+        self,
+        game_slug=None,
+        installer_file=None,
+        revision=None,
+        parent=None,
+        application=None,
     ):
         super().__init__(application=application)
 
@@ -46,6 +47,8 @@ class InstallerWindow(BaseApplicationWindow):
         self.game_slug = game_slug
         self.installer_file = installer_file
         self.revision = revision
+        self.desktop_shortcut_box = None
+        self.menu_shortcut_box = None
 
         self.log_buffer = None
         self.log_textview = None
@@ -71,49 +74,45 @@ class InstallerWindow(BaseApplicationWindow):
         action_buttons_alignment.add(self.action_buttons)
         self.vbox.pack_start(action_buttons_alignment, False, True, 0)
 
-        self.cancel_button = Gtk.Button.new_with_mnemonic("C_ancel")
-        self.cancel_button.set_tooltip_text("Abort and revert the installation")
-        self.cancel_button.connect("clicked", self.cancel_installation)
-        self.action_buttons.add(self.cancel_button)
-
-        self.eject_button = self.add_button("_Eject", self.on_eject_clicked)
-        self.source_button = self.add_button("_View source", self.on_source_clicked)
-        self.install_button = self.add_button("_Install", self.on_install_clicked)
-        self.continue_button = self.add_button("_Continue")
-        self.play_button = self.add_button("_Launch", self.launch_game)
-        self.close_button = self.add_button("_Close", self.on_destroy)
+        self.manual_button = self.add_button(_("Configure m_anually"), self.on_manual_clicked)
+        self.cancel_button = self.add_button(
+            _("C_ancel"), self.cancel_installation, tooltip=_("Abort and revert the installation")
+        )
+        self.eject_button = self.add_button(_("_Eject"), self.on_eject_clicked)
+        self.source_button = self.add_button(_("_View source"), self.on_source_clicked)
+        self.install_button = self.add_button(_("_Install"), self.on_install_clicked)
+        self.continue_button = self.add_button(_("_Continue"))
+        self.play_button = self.add_button(_("_Launch"), self.launch_game)
+        self.close_button = self.add_button(_("_Close"), self.on_destroy)
 
         self.continue_handler = None
 
         # check if installer is local or online
         if system.path_exists(self.installer_file):
-            self.get_scripts(local_script=True)
+            self.on_scripts_obtained(interpreter.read_script(self.installer_file))
         else:
-            self.title_label.set_markup("Waiting for response from %s" % (settings.SITE_URL))
+            self.title_label.set_markup(_("Waiting for response from %s") % (settings.SITE_URL))
             self.add_spinner()
             self.widget_box.show()
             self.title_label.show()
-            self.get_scripts(local_script=False)
-
-        self.present()
-
-    def add_button(self, label, handler=None):
-        button = Gtk.Button.new_with_mnemonic(label)
-        if handler:
-            button.connect("clicked", handler)
-        self.action_buttons.add(button)
-        return button
-
-    def get_scripts(self, local_script=False):
-        if local_script:
-            self.on_scripts_obtained(interpreter.read_script(self.installer_file))
-        else:
             jobs.AsyncCall(
                 interpreter.fetch_script,
                 self.on_scripts_obtained,
                 self.game_slug,
                 self.revision,
             )
+        self.present()
+
+    def add_button(self, label, handler=None, tooltip=None):
+        """Add a button to the action buttons box"""
+        button = Gtk.Button.new_with_mnemonic(label)
+        if tooltip:
+            button.set_tooltip_text(tooltip)
+        if handler:
+            button.connect("clicked", handler)
+
+        self.action_buttons.add(button)
+        return button
 
     def on_scripts_obtained(self, scripts, _error=None):
         if not scripts:
@@ -140,31 +139,38 @@ class InstallerWindow(BaseApplicationWindow):
         """Open dialog for 'no script available' situation."""
         dlg = NoInstallerDialog(self)
         if dlg.result == dlg.MANUAL_CONF:
-            game_data = pga.get_game_by_field(self.game_slug, "slug")
-
-            if game_data and "slug" in game_data:
-                # Game data already exist locally.
-                game = Game(game_data["id"])
-            else:
-                # Try to load game data from remote.
-                games = api.get_api_games([self.game_slug])
-
-                if games and len(games) >= 1:
-                    remote_game = games[0]
-                    game_data = {
-                        "name": remote_game["name"],
-                        "slug": remote_game["slug"],
-                        "year": remote_game["year"],
-                        "updated": remote_game["updated"],
-                        "steamid": remote_game["steamid"],
-                    }
-                    game = Game(pga.add_game(**game_data))
-                else:
-                    game = None
-            AddGameDialog(self.parent, game=game)
+            self.manually_configure_game()
         elif dlg.result == dlg.NEW_INSTALLER:
             webbrowser.open(settings.GAME_URL % self.game_slug)
 
+    def manually_configure_game(self):
+        game_data = pga.get_game_by_field(self.game_slug, "slug")
+
+        if game_data and "slug" in game_data:
+            # Game data already exist locally.
+            game = Game(game_data["id"])
+        else:
+            # Try to load game data from remote.
+            games = api.get_api_games([self.game_slug])
+
+            if games and len(games) >= 1:
+                remote_game = games[0]
+                game_data = {
+                    "name": remote_game["name"],
+                    "slug": remote_game["slug"],
+                    "year": remote_game["year"],
+                    "updated": remote_game["updated"],
+                    "steamid": remote_game["steamid"],
+                }
+                game = Game(pga.add_game(**game_data))
+            else:
+                game = None
+        AddGameDialog(self.parent, game=game)
+
+    def on_manual_clicked(self, widget):
+        self.destroy()
+        self.manually_configure_game()
+
     def validate_scripts(self):
         """Auto-fixes some script aspects and checks for mandatory fields"""
         for script in self.scripts:
@@ -179,12 +185,10 @@ class InstallerWindow(BaseApplicationWindow):
         """Stage where we choose an install script."""
         self.validate_scripts()
         base_script = self.scripts[0]
-        self.title_label.set_markup("<b>Install %s</b>" % escape_gtk_label(base_script["name"]))
+        self.title_label.set_markup(_("<b>Install %s</b>") % escape_gtk_label(base_script["name"]))
         installer_picker = InstallerPicker(self.scripts)
         installer_picker.connect("installer-selected", self.on_installer_selected)
-        scrolledwindow = Gtk.ScrolledWindow(
-            hexpand=True, vexpand=True, child=installer_picker
-        )
+        scrolledwindow = Gtk.ScrolledWindow(hexpand=True, vexpand=True, child=installer_picker)
         scrolledwindow.set_shadow_type(Gtk.ShadowType.ETCHED_IN)
         self.widget_box.pack_end(scrolledwindow, True, True, 10)
         scrolledwindow.show()
@@ -201,8 +205,8 @@ class InstallerWindow(BaseApplicationWindow):
         except MissingGameDependency as ex:
             dlg = QuestionDialog(
                 {
-                    "question": "This game requires %s. Do you want to install it?" % ex.slug,
-                    "title": "Missing dependency",
+                    "question": _("This game requires %s. Do you want to install it?") % ex.slug,
+                    "title": _("Missing dependency"),
                 }
             )
             if dlg.result == Gtk.ResponseType.YES:
@@ -214,28 +218,25 @@ class InstallerWindow(BaseApplicationWindow):
             self.destroy()
             return
 
-        self.title_label.set_markup(
-            u"<b>Installing {}</b>".format(
-                escape_gtk_label(self.interpreter.game_name)
-            )
-        )
+        self.title_label.set_markup(_(u"<b>Installing {}</b>").format(escape_gtk_label(self.interpreter.game_name)))
         self.select_install_folder()
 
     def select_install_folder(self):
         """Stage where we select the install directory."""
         if self.interpreter.creates_game_folder:
-            self.set_message("Select installation directory")
+            self.set_message(_("Select installation directory"))
             default_path = self.interpreter.get_default_target()
             self.set_path_chooser(self.on_target_changed, "folder", default_path)
 
         else:
-            self.set_message("Click install to continue")
+            self.set_message(_("Click install to continue"))
         if self.continue_handler:
             self.continue_button.disconnect(self.continue_handler)
         self.continue_button.hide()
         self.source_button.show()
         self.install_button.grab_focus()
         self.install_button.show()
+        self.manual_button.hide()
 
     def on_installer_selected(self, widget, installer_slug):
         self.clean_widgets()
@@ -255,19 +256,14 @@ class InstallerWindow(BaseApplicationWindow):
         self.clean_widgets()
         self.set_message(message)
         path = self.selected_directory or os.path.expanduser("~")
-        self.set_path_chooser(
-            self.continue_guard,
-            "file",
-            default_path=path
-        )
+        self.set_path_chooser(self.continue_guard, "file", default_path=path)
 
     def continue_guard(self, _, action):
         """This is weird and needs to be explained."""
         path = os.path.expanduser(self.location_entry.get_text())
         if (
-                action == Gtk.FileChooserAction.OPEN and os.path.isfile(path)
-        ) or (
-                action == Gtk.FileChooserAction.SELECT_FOLDER and os.path.isdir(path)
+            (action == Gtk.FileChooserAction.OPEN and os.path.isfile(path))
+            or (action == Gtk.FileChooserAction.SELECT_FOLDER and os.path.isdir(path))
         ):
             self.continue_button.set_sensitive(True)
             self.continue_button.connect("clicked", self.on_file_selected)
@@ -282,29 +278,25 @@ class InstallerWindow(BaseApplicationWindow):
         self.continue_button.set_sensitive(False)
 
         if action == "file":
-            title = "Select file"
+            title = _("Select file")
             action = Gtk.FileChooserAction.OPEN
             enable_warnings = False
         elif action == "folder":
-            title = "Select folder"
+            title = _("Select folder")
             action = Gtk.FileChooserAction.SELECT_FOLDER
             enable_warnings = True
         else:
-            raise ValueError("Invalid action %s", action)
+            raise ValueError("Invalid action %s" % action)
 
         if self.location_entry:
             self.location_entry.destroy()
         self.location_entry = FileChooserEntry(
-            title,
-            action,
-            path=default_path,
-            warn_if_non_empty=enable_warnings,
-            warn_if_ntfs=enable_warnings
+            title, action, path=default_path, warn_if_non_empty=enable_warnings, warn_if_ntfs=enable_warnings
         )
         self.location_entry.entry.connect("changed", callback_on_changed, action)
         self.widget_box.pack_start(self.location_entry, False, False, 0)
 
-    def on_file_selected(self, widget):
+    def on_file_selected(self, _widget):
         file_path = os.path.expanduser(self.location_entry.get_text())
         if os.path.isfile(file_path):
             self.selected_directory = os.path.dirname(file_path)
@@ -313,13 +305,15 @@ class InstallerWindow(BaseApplicationWindow):
             return
         self.interpreter.file_selected(file_path)
 
-    def start_download(
-        self, file_uri, dest_file, callback=None, data=None, referer=None
-    ):
+    def start_download(self, file_uri, dest_file, callback=None, data=None, referer=None):
         self.clean_widgets()
         logger.debug("Downloading %s to %s", file_uri, dest_file)
         self.download_progress = DownloadProgressBox(
-            {"url": file_uri, "dest": dest_file, "referer": referer}, cancelable=True
+            {
+                "url": file_uri,
+                "dest": dest_file,
+                "referer": referer
+            }, cancelable=True
         )
         self.download_progress.cancel_button.hide()
         self.download_progress.connect("complete", self.on_download_complete, callback, data)
@@ -354,22 +348,20 @@ class InstallerWindow(BaseApplicationWindow):
         buttons_box.set_margin_bottom(40)
         self.widget_box.add(buttons_box)
 
-        autodetect_button = Gtk.Button(label="Autodetect")
+        autodetect_button = Gtk.Button(label=_("Autodetect"))
         autodetect_button.connect("clicked", callback, requires)
         autodetect_button.grab_focus()
         autodetect_button.show()
         buttons_box.pack_start(autodetect_button, True, True, 40)
 
-        browse_button = Gtk.Button(label="Browse…")
+        browse_button = Gtk.Button(label=_("Browse…"))
         callback_data = {"callback": callback, "requires": requires}
         browse_button.connect("clicked", self.on_browse_clicked, callback_data)
         browse_button.show()
         buttons_box.pack_start(browse_button, True, True, 40)
 
     def on_browse_clicked(self, widget, callback_data):
-        dialog = DirectoryDialog(
-            "Select the folder where the disc is mounted", parent=self
-        )
+        dialog = DirectoryDialog(_("Select the folder where the disc is mounted"), parent=self)
         folder = dialog.folder
         callback = callback_data["callback"]
         requires = callback_data["requires"]
@@ -398,9 +390,7 @@ class InstallerWindow(BaseApplicationWindow):
 
         combobox.connect("changed", self.on_input_menu_changed)
         combobox.show()
-        self.continue_handler = self.continue_button.connect(
-            "clicked", callback, alias, combobox
-        )
+        self.continue_handler = self.continue_button.connect("clicked", callback, alias, combobox)
         self.continue_button.grab_focus()
         self.continue_button.show()
 
@@ -414,8 +404,8 @@ class InstallerWindow(BaseApplicationWindow):
         self.clean_widgets()
         self.install_in_progress = False
 
-        self.desktop_shortcut_box = Gtk.CheckButton("Create desktop shortcut")
-        self.menu_shortcut_box = Gtk.CheckButton("Create application menu " "shortcut")
+        self.desktop_shortcut_box = Gtk.CheckButton(_("Create desktop shortcut"))
+        self.menu_shortcut_box = Gtk.CheckButton(_("Create application menu shortcut"))
         self.widget_box.pack_start(self.desktop_shortcut_box, False, False, 5)
         self.widget_box.pack_start(self.menu_shortcut_box, False, False, 5)
         self.widget_box.show_all()
@@ -481,14 +471,14 @@ class InstallerWindow(BaseApplicationWindow):
 
     def cancel_installation(self, widget=None):
         """Ask a confirmation before cancelling the install"""
-        remove_checkbox = Gtk.CheckButton.new_with_label("Remove game files")
+        remove_checkbox = Gtk.CheckButton.new_with_label(_("Remove game files"))
         if self.interpreter:
             remove_checkbox.set_active(self.interpreter.game_dir_created)
             remove_checkbox.show()
         confirm_cancel_dialog = QuestionDialog(
             {
-                "question": "Are you sure you want to cancel the installation?",
-                "title": "Cancel installation?",
+                "question": _("Are you sure you want to cancel the installation?"),
+                "title": _("Cancel installation?"),
                 "widgets": [remove_checkbox]
             }
         )
@@ -501,9 +491,7 @@ class InstallerWindow(BaseApplicationWindow):
         self.destroy()
 
     def on_source_clicked(self, _button):
-        InstallerSourceDialog(
-            self.interpreter.script_pretty, self.interpreter.game_name, self
-        )
+        InstallerSourceDialog(self.interpreter.script_pretty, self.interpreter.game_name, self)
 
     def clean_widgets(self):
         """Cleanup before displaying the next stage."""
@@ -534,9 +522,7 @@ class InstallerWindow(BaseApplicationWindow):
         self.log_buffer = Gtk.TextBuffer()
         command.set_log_buffer(self.log_buffer)
         self.log_textview = LogTextView(self.log_buffer)
-        scrolledwindow = Gtk.ScrolledWindow(
-            hexpand=True, vexpand=True, child=self.log_textview
-        )
+        scrolledwindow = Gtk.ScrolledWindow(hexpand=True, vexpand=True, child=self.log_textview)
         scrolledwindow.set_shadow_type(Gtk.ShadowType.ETCHED_IN)
         self.widget_box.pack_end(scrolledwindow, True, True, 10)
         scrolledwindow.show()
